@@ -2,33 +2,17 @@
 # SPDX-License-Identifier: MIT
 
 import collections
-import copy
 import re
 import urllib.parse
 from abc import ABC, abstractmethod
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Dict,
-    Iterable,
-    List,
-    Optional,
-    Tuple,
-    Union,
-    cast,
-    overload,
-)
+from typing import Iterable, List, Optional, Tuple, Union, cast, overload
 
 from specfile.exceptions import DuplicateSourceException
 from specfile.formatter import formatted
-from specfile.macros import Macros
 from specfile.sourcelist import Sourcelist, SourcelistEntry
 from specfile.tags import Comments, Tag, Tags
 from specfile.utils import get_filename_from_location
 
-if TYPE_CHECKING:
-    from specfile.specfile import Specfile
-
 
 class Source(ABC):
     """Class that represents a source."""
@@ -252,7 +236,6 @@ class Sources(collections.abc.MutableSequence):
         allow_duplicates: bool = False,
         default_to_implicit_numbering: bool = False,
         default_source_number_digits: int = 1,
-        context: Optional["Specfile"] = None,
     ) -> None:
         """
         Constructs a `Sources` object.
@@ -273,7 +256,6 @@ class Sources(collections.abc.MutableSequence):
         self._allow_duplicates = allow_duplicates
         self._default_to_implicit_numbering = default_to_implicit_numbering
         self._default_source_number_digits = default_source_number_digits
-        self._context = context
 
     def __eq__(self, other: object) -> bool:
         if not isinstance(other, Sources):
@@ -295,19 +277,9 @@ class Sources(collections.abc.MutableSequence):
         return (
             f"{self.__class__.__name__}({self._tags!r}, {self._sourcelists!r}, "
             f"{self._allow_duplicates!r}, {self._default_to_implicit_numbering!r}, "
-            f"{self._default_source_number_digits!r}, {self._context!r})"
+            f"{self._default_source_number_digits!r})"
         )
 
-    def __deepcopy__(self, memo: Dict[int, Any]) -> "Sources":
-        result = self.__class__.__new__(self.__class__)
-        memo[id(self)] = result
-        for k, v in self.__dict__.items():
-            if k == "_context":
-                continue
-            setattr(result, k, copy.deepcopy(v, memo))
-        result._context = self._context
-        return result
-
     def __contains__(self, location: object) -> bool:
         items = self._get_items()
         if not items:
@@ -364,11 +336,6 @@ class Sources(collections.abc.MutableSequence):
             _, container, index = items[i]
             del container[index]
 
-    def _expand(self, s: str) -> str:
-        if self._context:
-            return self._context.expand(s)
-        return Macros.expand(s)
-
     def _get_tags(self) -> List[Tuple[TagSource, Tags, int]]:
         """
         Gets all tag sources.
@@ -535,7 +502,7 @@ class Sources(collections.abc.MutableSequence):
                 name, separator = self._get_tag_format(cast(TagSource, source), number)
                 container.insert(
                     index,
-                    Tag(name, location, self._expand(location), separator, Comments()),
+                    Tag(name, location, separator, Comments()),
                 )
                 self._deduplicate_tag_names(i)
             else:
@@ -549,7 +516,7 @@ class Sources(collections.abc.MutableSequence):
             index, name, separator = self._get_initial_tag_setup()
             self._tags.insert(
                 index,
-                Tag(name, location, self._expand(location), separator, Comments()),
+                Tag(name, location, separator, Comments()),
             )
 
     def insert_numbered(self, number: int, location: str) -> int:
@@ -582,9 +549,7 @@ class Sources(collections.abc.MutableSequence):
         else:
             i = 0
             index, name, separator = self._get_initial_tag_setup(number)
-        self._tags.insert(
-            index, Tag(name, location, self._expand(location), separator, Comments())
-        )
+        self._tags.insert(index, Tag(name, location, separator, Comments()))
         self._deduplicate_tag_names(i)
         return i
 
