@@ -312,7 +312,12 @@ class ValueParser:
 
         def expand(s):
             if context:
-                return context.expand(s)
+                result = context.expand(
+                    s, skip_parsing=getattr(expand, "skip_parsing", False)
+                )
+                # parse only once
+                expand.skip_parsing = True
+                return result
             return Macros.expand(s)
 
         def flatten(nodes):
